# ddtcurve

A package used to calculate the strength of the ddtank game.

- Contact the author: jugking6688@gmail.com
---

Examples are as follows：
```python
import ddtcurve as ddtc

result = ddtc.predict(65, 0, 10, 0)
print(result)

result = ddtc.predict(65, 1, 10, 0)
print(result)

result = ddtc.predict(65, 0, 10, 1)
print(result)
```
Output:
```
56.984355730170684
54.693446341504185
58.14777549325182
```

`Remarks:`

`There are many authors who have contributed to this package. :)`







